Struct Nvdimm
Source #[repr(C, packed(1))]
pub struct Nvdimm {
pub header: DevicePathProtocol,
pub nfit_device_handle: u32,
}
nfit_device_handle: u32
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.